[svn-commits] file: branch file/chan_jingle2 r369530 - in /team/file/chan_jingle2: channels...

SVN commits to the Digium repositories svn-commits at lists.digium.com
Mon Jul 2 11:51:49 CDT 2012


Author: file
Date: Mon Jul  2 11:51:45 2012
New Revision: 369530

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=369530
Log:
Some renaming! Jingle2 -> Motif.

Added:
    team/file/chan_jingle2/configs/motif.conf.sample
      - copied unchanged from r368681, team/file/chan_jingle2/configs/jingle2.conf.sample
Removed:
    team/file/chan_jingle2/configs/jingle2.conf.sample
Modified:
    team/file/chan_jingle2/channels/chan_jingle2.c

Modified: team/file/chan_jingle2/channels/chan_jingle2.c
URL: http://svnview.digium.com/svn/asterisk/team/file/chan_jingle2/channels/chan_jingle2.c?view=diff&rev=369530&r1=369529&r2=369530
==============================================================================
--- team/file/chan_jingle2/channels/chan_jingle2.c (original)
+++ team/file/chan_jingle2/channels/chan_jingle2.c Mon Jul  2 11:51:45 2012
@@ -20,7 +20,7 @@
  *
  * \author Joshua Colp <jcolp at digium.com>
  *
  * \brief Jingle Channel Driver
  *
  * \extref Iksemel http://iksemel.jabberstudio.org/
  *
@@ -68,9 +68,6 @@
 #include "asterisk/astobj.h"
 #include "asterisk/abstract_jb.h"
 #include "asterisk/jabber.h"
-
-/*! \brief Default filename for the configuration file */
-#define JINGLE_CONFIG "jingle2.conf"
 
 /*! \brief Default maximum number of ICE candidates we will offer */
 #define DEFAULT_MAX_ICE_CANDIDATES "10"
@@ -176,7 +173,7 @@
 };
 
 static const char desc[] = "Jingle Channel";
-static const char channel_type[] = "Jingle2";
+static const char channel_type[] = "Motif";
 
 struct jingle_config {
 	struct ao2_container *endpoints; /*!< Configured endpoints */
@@ -410,7 +407,7 @@
 struct aco_type *endpoint_options[] = ACO_TYPES(&endpoint_option);
 
 struct aco_file jingle_conf = {
-	.filename = "jingle2.conf",
+	.filename = "motif.conf",
 	.types = ACO_TYPES(&endpoint_option),
 };
 
@@ -2427,7 +2424,7 @@
 	}
 
 	if (aco_info_init(&cfg_info)) {
-		ast_log(LOG_ERROR, "Unable to intialize configuration for chan_jingle2.\n");
+		ast_log(LOG_ERROR, "Unable to intialize configuration for chan_motif.\n");
 		goto end;
 	}
 
@@ -20,7 +20,7 @@
  * \author Joshua Colp <jcolp at digium.com>
  *
- * \brief Jingle Channel Driver
+ * \brief Motif (Jingle) Jingle Channel Driver
  *
  * \extref Iksemel http://iksemel.jabberstudio.org/




More information about the svn-commits mailing list